Video demo on YouTube : https://youtu.be/PMLaksRtqyk
# Pywaremon: Glance on your computer status
# Works on everything running \*NIX, Mac, Windows, anything Python

I present a little 8kb Python file that will show you at a glance the resources being used on the machine
This includes CPU, Memory, Storage, and both IN and OUT IP address (thanks to ipify API (more here:https://api.ipify.org))

Here are some settings that you can change, they're at the top of tbe Python script

	Refresh = default refresh rate, aka the time for intervals (in seconds). Can be float, e.g. 0.2
	But I like 0.5 !
# refresh = 0.5

	At the bottom are some waves, at least, it aims to be.
	Set this to (True) to enable, or (False) to disable this amazing feature. I mean. Why should you?
# dowave = True

	The top and bottom banners (Title / Wavey thingy) change color. Same as before:
	Set this to (True) to enable, or (False) to disable this amazing feature. I mean. Why should you?
# changeColor = True

Oh yeah, probably you can guess, but I tell you anyway.
This sheet is colorful as fook!
It has unnecesary fancy stuff in it.
I guess humans like it.
I'm working on implementing more feautures to be changes.

![image](https://user-images.githubusercontent.com/36036245/48550671-ba87b700-e8d3-11e8-949a-e58c2287651d.png)
